`pyctpp2 <http:http://bitbucket.org/klepa/pyctpp2>`_ bindings for Pyramid
=========================================================================

These are bindings for the `pyctpp2 templating system
<http:http://bitbucket.org/klepa/pyctpp2>`_ for the `Pyramid
<http://docs.pylonshq.com/>`_ web framework.

